Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1143)

Unified Diff: runtime/vm/intrinsifier.cc

Issue 14426006: Rename dart:typeddata to dart:typed_data. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/intrinsifier.h ('k') | runtime/vm/intrinsifier_arm.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/intrinsifier.cc
diff --git a/runtime/vm/intrinsifier.cc b/runtime/vm/intrinsifier.cc
index f7303a92aa2dc26f5cec5afdfea59be82d7f200d..068c817fa984f2a8104c2c11755e59ccd70c0b7f 100644
--- a/runtime/vm/intrinsifier.cc
+++ b/runtime/vm/intrinsifier.cc
@@ -123,9 +123,9 @@ void Intrinsifier::InitializeState() {
lib = Library::MathLibrary();
MATH_LIB_INTRINSIC_LIST(SETUP_FUNCTION);
// Set up all dart:typeddata lib functions that can be intrisified.
lib = Library::TypedDataLibrary();
- TYPEDDATA_LIB_INTRINSIC_LIST(SETUP_FUNCTION);
+ TYPED_DATA_LIB_INTRINSIC_LIST(SETUP_FUNCTION);
#undef SETUP_FUNCTION
}
@@ -150,7 +150,7 @@ bool Intrinsifier::Intrinsify(const Function& function, Assembler* assembler) {
if (lib.raw() == Library::CoreLibrary()) {
CORE_LIB_INTRINSIC_LIST(FIND_INTRINSICS);
} else if (lib.raw() == Library::TypedDataLibrary()) {
- TYPEDDATA_LIB_INTRINSIC_LIST(FIND_INTRINSICS);
+ TYPED_DATA_LIB_INTRINSIC_LIST(FIND_INTRINSICS);
} else if (lib.raw() == Library::MathLibrary()) {
MATH_LIB_INTRINSIC_LIST(FIND_INTRINSICS);
}
@@ -123,9 +123,9 @@ void Intrinsifier::InitializeState() {
lib = Library::MathLibrary();
MATH_LIB_INTRINSIC_LIST(SETUP_FUNCTION);
- // Set up all dart:typeddata lib functions that can be intrisified.
+ // Set up all dart:typed_data lib functions that can be intrisified.
lib = Library::TypedDataLibrary();
« no previous file with comments | « runtime/vm/intrinsifier.h ('k') | runtime/vm/intrinsifier_arm.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698